import type { ErrorResponse } from "../errorResponse";
import { ClientHttpError } from "../httpError";
export declare const CONFLICT_STATUS: 409;
export type ConflictErrorResponse = ErrorResponse & {
    status: typeof CONFLICT_STATUS;
};
/**
 * Runtime error thrown on HTTP Conflict (409) response.
 *
 * @see {@link https://www.rfc-editor.org/rfc/rfc9110#status.409 | RFC 9110 (15.5.10.) 409 Conflict}
 * @since 0.0.1
 */
export declare class ConflictError extends ClientHttpError {
    constructor(responseMetadata: {
        status: number;
        statusText: string;
        headers: Headers;
        url: string;
    }, responseBody: string, message: string, options?: ErrorOptions);
    get response(): ConflictErrorResponse;
}
export default ConflictError;
