import type { ErrorResponse } from "../errorResponse";
import { ClientHttpError } from "../httpError";
export declare const FORBIDDEN_STATUS: 403;
export type ForbiddenErrorResponse = ErrorResponse & {
    status: typeof FORBIDDEN_STATUS;
};
/**
 * Runtime error thrown on HTTP Forbidden (403) response.
 *
 * @see {@link https://www.rfc-editor.org/rfc/rfc9110#status.403 | RFC 9110 (15.5.4.) 403 Forbidden}
 * @since 0.0.1
 */
export declare class ForbiddenError extends ClientHttpError {
    constructor(responseMetadata: {
        status: number;
        statusText: string;
        headers: Headers;
        url: string;
    }, responseBody: string, message: string, options?: ErrorOptions);
    get response(): ForbiddenErrorResponse;
}
export default ForbiddenError;
