import type { ErrorResponse } from "../errorResponse";
import { ClientHttpError } from "../httpError";
export declare const GONE_STATUS: 410;
export type GoneErrorResponse = ErrorResponse & {
    status: typeof GONE_STATUS;
};
/**
 * Runtime error thrown on HTTP Gone (410) response.
 *
 * @see {@link https://www.rfc-editor.org/rfc/rfc9110#status.410 | RFC 9110 (15.5.11.) 410 Gone}
 * @since 0.0.1
 */
export declare class GoneError extends ClientHttpError {
    constructor(responseMetadata: {
        status: number;
        statusText: string;
        headers: Headers;
        url: string;
    }, responseBody: string, message: string, options?: ErrorOptions);
    get response(): GoneErrorResponse;
}
export default GoneError;
