import type { ErrorResponse } from "../errorResponse";
import { ClientHttpError } from "../httpError";
export declare const METHOD_NOT_ALLOWED_STATUS: 405;
export type MethodNotAllowedErrorResponse = ErrorResponse & {
    status: typeof METHOD_NOT_ALLOWED_STATUS;
};
/**
 * Runtime error thrown on HTTP Method Not Allowed (405) response.
 *
 * @see {@link https://www.rfc-editor.org/rfc/rfc9110#status.405 | RFC 9110 (15.5.6.) 405 Method Not Allowed}
 * @since 0.0.1
 */
export declare class MethodNotAllowedError extends ClientHttpError {
    constructor(responseMetadata: {
        status: number;
        statusText: string;
        headers: Headers;
        url: string;
    }, responseBody: string, message: string, options?: ErrorOptions);
    get response(): MethodNotAllowedErrorResponse;
}
export default MethodNotAllowedError;
