import type { ErrorResponse } from "../errorResponse";
import { ClientHttpError } from "../httpError";
export declare const NOT_ACCEPTABLE_STATUS: 406;
export type NotAcceptableErrorResponse = ErrorResponse & {
    status: typeof NOT_ACCEPTABLE_STATUS;
};
/**
 * Runtime error thrown on HTTP Not Acceptable (406) response.
 *
 * @see {@link https://www.rfc-editor.org/rfc/rfc9110#status.406 | RFC 9110 (15.5.7.) 406 Not Acceptable}
 * @since 0.0.1
 */
export declare class NotAcceptableError extends ClientHttpError {
    constructor(responseMetadata: {
        status: number;
        statusText: string;
        headers: Headers;
        url: string;
    }, responseBody: string, message: string, options?: ErrorOptions);
    get response(): NotAcceptableErrorResponse;
}
export default NotAcceptableError;
