import type { ErrorResponse } from "../errorResponse";
import { ClientHttpError } from "../httpError";
export declare const NOT_FOUND_STATUS: 404;
export type NotFoundErrorResponse = ErrorResponse & {
    status: typeof NOT_FOUND_STATUS;
};
/**
 * Runtime error thrown on HTTP Not Found (404) response.
 *
 * @see {@link https://www.rfc-editor.org/rfc/rfc9110#status.404 | RFC 9110 (15.5.5.) 404 Not Found}
 * @since 0.0.1
 */
export declare class NotFoundError extends ClientHttpError {
    constructor(responseMetadata: {
        status: number;
        statusText: string;
        headers: Headers;
        url: string;
    }, responseBody: string, message: string, options?: ErrorOptions);
    get response(): NotFoundErrorResponse;
}
export default NotFoundError;
