import type { ErrorResponse } from "../errorResponse";
import { ClientHttpError } from "../httpError";
export declare const PRECONDITION_FAILED_STATUS: 412;
export type PreconditionFailedErrorResponse = ErrorResponse & {
    status: typeof PRECONDITION_FAILED_STATUS;
};
/**
 * Runtime error thrown on HTTP Precondition Failed (412) response.
 *
 * @see {@link https://www.rfc-editor.org/rfc/rfc9110#status.412 | RFC 9110 (15.5.13.) 412 Precondition Failed}
 * @since 0.0.1
 */
export declare class PreconditionFailedError extends ClientHttpError {
    constructor(responseMetadata: {
        status: number;
        statusText: string;
        headers: Headers;
        url: string;
    }, responseBody: string, message: string, options?: ErrorOptions);
    get response(): PreconditionFailedErrorResponse;
}
export default PreconditionFailedError;
