import type { ErrorResponse } from "../errorResponse";
import { ClientHttpError } from "../httpError";
export declare const TOO_MANY_REQUESTS_STATUS: 429;
export type TooManyRequestsErrorResponse = ErrorResponse & {
    status: typeof TOO_MANY_REQUESTS_STATUS;
};
/**
 * Runtime error thrown on HTTP Too Many Requests (429) response.
 *
 * @see {@link https://www.rfc-editor.org/rfc/rfc6585#section-4 | RFC 6585 (4.) 429 Too Many Requests}
 * @since 0.0.1
 */
export declare class TooManyRequestsError extends ClientHttpError {
    constructor(responseMetadata: {
        status: number;
        statusText: string;
        headers: Headers;
        url: string;
    }, responseBody: string, message: string, options?: ErrorOptions);
    get response(): TooManyRequestsErrorResponse;
}
export default TooManyRequestsError;
