import type { ErrorResponse } from "../errorResponse";
import { ClientHttpError } from "../httpError";
export declare const UNAUTHORIZED_STATUS: 401;
export type UnauthorizedErrorResponse = ErrorResponse & {
    status: typeof UNAUTHORIZED_STATUS;
};
/**
 * Runtime error thrown on HTTP Unauthorized (401) response.
 *
 * @see {@link https://www.rfc-editor.org/rfc/rfc9110#status.401 | RFC 9110 (15.5.2.) 401 Unauthorized}
 * @since 0.0.1
 */
export declare class UnauthorizedError extends ClientHttpError {
    constructor(responseMetadata: {
        status: number;
        statusText: string;
        headers: Headers;
        url: string;
    }, responseBody: string, message: string, options?: ErrorOptions);
    get response(): UnauthorizedErrorResponse;
}
export default UnauthorizedError;
