import type { ErrorResponse } from "../errorResponse";
import { ClientHttpError } from "../httpError";
export declare const UNSUPPORTED_MEDIA_TYPE_STATUS: 415;
export type UnsupportedMediaTypeErrorResponse = ErrorResponse & {
    status: typeof UNSUPPORTED_MEDIA_TYPE_STATUS;
};
/**
 * Runtime error thrown on HTTP Unsupported Media Type (415) response.
 *
 * @see {@link https://www.rfc-editor.org/rfc/rfc9110#status.415 | RFC 9110 (15.5.16.) 415 Unsupported Media Type}
 * @since 0.0.1
 */
export declare class UnsupportedMediaTypeError extends ClientHttpError {
    constructor(responseMetadata: {
        status: number;
        statusText: string;
        headers: Headers;
        url: string;
    }, responseBody: string, message: string, options?: ErrorOptions);
    get response(): UnsupportedMediaTypeErrorResponse;
}
export default UnsupportedMediaTypeError;
